<?php

namespace Litecms\MatchingCommission\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\MatchingCommission\Models\MatchingCommission;

class MatchingCommissionPolicy
{

    /**
     * Determine if the given user can view the matching_commission.
     *
     * @param UserPolicy $user
     * @param MatchingCommission $matching_commission
     *
     * @return bool
     */
    public function view(UserPolicy $user, MatchingCommission $matching_commission)
    {
        if ($user->canDo('matching_commission.matching_commission.view') && $user->isAdmin()) {
            return true;
        }

        return $matching_commission->user_id == user_id() && $matching_commission->user_type == user_type();
    }

    /**
     * Determine if the given user can create a matching_commission.
     *
     * @param UserPolicy $user
     * @param MatchingCommission $matching_commission
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('matching_commission.matching_commission.create');
    }

    /**
     * Determine if the given user can update the given matching_commission.
     *
     * @param UserPolicy $user
     * @param MatchingCommission $matching_commission
     *
     * @return bool
     */
    public function update(UserPolicy $user, MatchingCommission $matching_commission)
    {
        if ($user->canDo('matching_commission.matching_commission.edit') && $user->isAdmin()) {
            return true;
        }

        return $matching_commission->user_id == user_id() && $matching_commission->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given matching_commission.
     *
     * @param UserPolicy $user
     * @param MatchingCommission $matching_commission
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MatchingCommission $matching_commission)
    {
        return $matching_commission->user_id == user_id() && $matching_commission->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given matching_commission.
     *
     * @param UserPolicy $user
     * @param MatchingCommission $matching_commission
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MatchingCommission $matching_commission)
    {
        if ($user->canDo('matching_commission.matching_commission.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given matching_commission.
     *
     * @param UserPolicy $user
     * @param MatchingCommission $matching_commission
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MatchingCommission $matching_commission)
    {
        if ($user->canDo('matching_commission.matching_commission.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
