<?php

namespace Litecms\MatchingCommission\Providers;

use Illuminate\Support\ServiceProvider;

class MatchingCommissionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'matching_commission');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'matching_commission');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.matching_commission', function ($app) {
            return $this->app->make('Litecms\MatchingCommission\MatchingCommission');
        });

                // Bind MatchingCommission to repository
        $this->app->bind(
            'Litecms\MatchingCommission\Interfaces\MatchingCommissionRepositoryInterface',
            \Litecms\MatchingCommission\Repositories\Eloquent\MatchingCommissionRepository::class
        );

        $this->app->register(\Litecms\MatchingCommission\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\MatchingCommission\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.matching_commission'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/matching_commission.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/matching_commission')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/matching_commission')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
